VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "ThisWorkbook"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = True
'/*======================================================================*/
'/* Source:     ThisWorkbook class module of this SRIMfit workbook
'/* Description: Init. / Term. procedures
'/*     1. regstration of SRIMfit funcs as UserMacro Functions
'/*     2. open/close MySRwb
'/* Coded:
'/*  Ver.3.12 18.10/09 Ay add #IF VBA7
'/*  Ver.3.00 17.04/05 Ay use external data file as MySRwb
'/*  Ver.2.10 16.11/05 A.Yoshida(RIKEN) AddIn module initialize
'/*======================================================================*/

Option Explicit
Option Base 1

'/*----------------------------------------------------------------------*/
'/* Def. Work Sheet Structure
'/*----------------------------------------------------------------------*/
Private Const WSFn = "FncHelp" ' Work sheet name of Function Help List
Private Const MaxArg = 9      ' max. num. of args.
Private Const ClmPrm = 4      ' Parameters for this macro
Private Const ClmFnm = 3      ' Func. Name
Private Const ClmNAg = 4      ' Num. of Args
Private Const ClmDsE = 5      ' Func. Description in English
Private Const ClmADE = 6      ' Arg.  Descr. in Eng.
Private Const ClmDsJ = 16     ' Func. Description in Japanese
Private Const ClmADJ = 17     ' Arg.  Descr. in Jpn.
Private Const RowLng = 6      ' Language mode of these descriptions
Private Const RowNFn = 7      ' Num. of Func defined
Private Const RowFDH = 8      ' Func. Description Header message
Private Const RowFDF = 9      ' Func. Description Footer message
Private Const RowADH = 10     ' Func. Arg. Description Header message
Private Const RowADF = 11     ' Func. Arg. Description Footer message
Private Const RowFnS = 15     ' Func list start pos.

'/*----------------------------------------------------------------------*/
'/* Def. Work Sheet Variables
'/*----------------------------------------------------------------------*/
Dim Lng As Integer          ' Language mode (0:Eng. 1:Jpn)
Dim Fcat As Variant         ' Category for these Func. def.
Dim nFn As Integer          ' Num. of Func defined
Dim ExclVer As Integer      ' Excel version
' Application.Version as String
' Excel 2016="16.0" 2013=15.0 2010=14.0 2007=12.0  : SRIMfit worked
'  2003=11.0 2002=10.0 2000=9.0 97=8.0 95=7.0 5.0=5.0

'/*----------------------------------------------------------------------*/
'/*     get info. from FncLst WS
'/*----------------------------------------------------------------------*/
Private Sub Fhelp_info()
'   Fcat = 14         ' User def. func. (1..32:Win 1..20:Mac)
    Fcat = "SRIMfit"
    ExclVer = Left(Application.Version, 2)
    With ThisWorkbook.Worksheets(WSFn)
        Lng = .Cells(RowLng, ClmPrm)
        nFn = .Cells(RowNFn, ClmPrm)
    End With
End Sub

'/*----------------------------------------------------------------------*/
'/*     Registration of SRIMfit funcs
'/*----------------------------------------------------------------------*/
Private Sub Fhelp_def()
Dim iRow As Integer, iClm As Integer, iCDsc As Integer
Dim iCArg As Integer, iArg As Integer
Dim FDhd As String, FDft As String      ' Func. Descr. Header/Footer
Dim ADhd As String, ADft As String      ' Arg. Descr. Header/Footer
Dim Fnm As String, Fdsc As String
Dim nArg As Integer
' Dim Farg(1 To MaxArg) As String
  Dim Farg() As String

'MsgBox "SRIMfit: Fhelp_def() enter"
'Stop
    Fhelp_info
    iCDsc = ClmDsE
    iCArg = ClmADE
    If Lng = 1 Then
        iCDsc = ClmDsJ
        iCArg = ClmADJ
    End If
    With ThisWorkbook.Worksheets(WSFn)
        FDhd = .Cells(RowFDH, iCDsc)
        FDft = .Cells(RowFDF, iCDsc)
        ADhd = .Cells(RowADH, iCDsc)
        ADft = .Cells(RowADF, iCDsc)
        For iRow = RowFnS To RowFnS + nFn - 1 Step 1
            Fnm = .Cells(iRow, ClmFnm)
            nArg = .Cells(iRow, ClmNAg)
            Fdsc = .Cells(iRow, iCDsc)
            Fdsc = FDhd + Fdsc + FDft
'           For iArg = 1 To MaxArg Step 1
'               Farg(iArg) = ""
'           Next iArg
            If nArg < 1 Then
                ReDim Farg(1)
            Else
                ReDim Farg(nArg)
                For iArg = 1 To nArg Step 1
                    Farg(iArg) = .Cells(iRow, iCArg + iArg - 1)
                    Farg(iArg) = ADhd + Farg(iArg) + ADft
                Next iArg
            End If
'           If ExclVer > 12 Then  is not suitable, gives compile error
#If VBA7 Then   ' for Excel 2010 or later
                Application.MacroOptions Macro:=Fnm, _
                    Description:=Fdsc, Category:=Fcat, _
                    ArgumentDescriptions:=Farg
#Else           ' for Excel2007 or under does NOT have ArgumentDescriptions
                Application.MacroOptions Macro:=Fnm, _
                    Description:=Fdsc, Category:=Fcat
#End If
        Next iRow
    End With
End Sub

'/*----------------------------------------------------------------------*/
'/*     Elimination of SRIMfit funcs
'/*----------------------------------------------------------------------*/
Private Sub Fhelp_undef()
Dim iRow, iClm, iCDsc, iCArg, iArg As Integer
Dim Fnm, Fdsc As String
Dim nArg As Integer
Dim Farg(1 To MaxArg) As String

'MsgBox "SRIMfit: Fhelp_undef() enter"
    Fhelp_info
    Fdsc = ""
    For iArg = 1 To MaxArg Step 1
        Farg(iArg) = ""
    Next iArg
    With ThisWorkbook.Worksheets(WSFn)
        For iRow = RowFnS To RowFnS + nFn - 1 Step 1
            Fnm = .Cells(iRow, ClmFnm)

#If VBA7 Then   ' for Excel 2010 or later
            Application.MacroOptions Macro:=Fnm, _
            Description:=Fdsc, Category:="", ArgumentDescriptions:=Farg
#Else           ' for Excel2007 or under does NOT have ArgumentDescriptions
            Application.MacroOptions Macro:=Fnm, _
            Description:=Fdsc, Category:=""
#End If

        Next iRow
    End With
End Sub


'/*----------------------------------------------------------------------*/
'/*     when SRIMfit.xlsm WorkBook opened / closed
'/*----------------------------------------------------------------------*/
Private Sub Workbook_Open()

'MsgBox "SRIMfit: WorkbookOpen() enter"
'Stop
    If ThisWorkbook.IsAddin = False Then
        Fhelp_def
    End If
    srMySRwb_open ("")
End Sub

Private Sub Workbook_BeforeClose(Cancel As Boolean)

'MsgBox "SRIMfit: WorkbookClose() enter"
    If ThisWorkbook.IsAddin = False Then
        Fhelp_undef
    End If
    srMySRwb_close
End Sub

'/*----------------------------------------------------------------------*/
'/*     when SRIMfit.xlam Addin opened / closed
'/*----------------------------------------------------------------------*/
Private Sub Workbook_AddinInstall()

'MsgBox "SRIMfit: AddInInstall() enter"
    Application.ScreenUpdating = False
    ThisWorkbook.IsAddin = False
    Fhelp_def
    ThisWorkbook.IsAddin = True
    ThisWorkbook.Saved = True
    Application.ScreenUpdating = True
End Sub

Private Sub Workbook_AddinUninstall()

'MsgBox "SRIMfit: AddInUninstall() enter"

'   Application.ScreenUpdating = False
'   ThisWorkbook.IsAddin = False
    Fhelp_undef
'   ThisWorkbook.IsAddin = True
'   ThisWorkbook.Saved = True
'   Application.ScreenUpdating = True
End Sub

